/**********************************************************************

	--- Qt Architect generated file ---

	File: GfWidget.h
	Last generated: Thu Jun 17 16:50:15 1999

 *********************************************************************/
/*

	for instrument control programs need to add:
	
		drawing of just line due at an added point
		
		saving of painting to QPixmap and refreshing the
		widget by a bitblt from the QPixmap.  Slows the 
		drawing by having to draw increments twice, but
		gives very fast refreshes.
		
		binary format dump to disk and restore.



*/
#ifndef GfWidget_included
#define GfWidget_included

#include "GfWidgetData.h"
#include "../gfcommon.h"
#include "../gffile.h"
#include "../gfdraw.h"
#include "../gfscale.h"
#include "../gfprofile.h"
#include <qpopupmenu.h>
#include <qapplication.h>

class GfWidget : public GfWidgetData
{
    Q_OBJECT

public:

    GfWidget
    (
        QWidget* parent = NULL,
        const char* name = NULL
    );

    virtual ~GfWidget();
    
    void setGfFile(const GfFile &);
    
    void setScale(const GfScale &);
    
    void setPlotDefs(const GfPlotDefs &);

    void setProfile(const GfProfile &);
    
    GfScale scale() const ;
    
    GfPlotDefs plotDefs() const;

    GfFile gfFile() const;
    
    void enablePopupMenu();
    void disablePopupMenu();
    
    QString fileName() const ;
    
    QPopupMenu *filePopupMenu();
    QPopupMenu *settingsPopupMenu();
    
    GfCurve curveSegment(int curve,int start,int end) const ;
    int deleteCurveSegment(int curve,int start,int end);
    int appendCurve(const GfCurve *,const GfScale &);
    
    int appendPoint(int,int, float,float );
    
    int appendPointDraw(int,int, float,float );
    
    int appendRow(int,int, float * );
    
    int appendRowDraw(int,int, float * );
    
    int setCurvePlotColumns(int,int,int);
    
    int getMaxMin(int curve,float *xmax,float *xmin,float *ymax,float *ymin) const ;
    
    int numCurves() const ;
    
    int numPoints() const ;
    
    void setInFileComments(const char *);
    
    int setPixmapRedraw(int ); // GF_YES or GF_NO
    
    // for use with overlays
    
    void draw(GfDraw *);
    void redrawLastPoint(GfDraw *,int c);
    
public slots:

	void saveAsPostscript();
	void open();
	void append();
	void saveAs();
	void rescale();
	void profile();
	void redraw();
	void comments();
	void curveFormat();
	void plotFormat();
	int read(QFile *,int,int,int append=GF_NO);
	void quit();
	void closeWin();
	int checkNumCols(QFile *);
	void autoScale();
	void setSelection(int curve,int start,int end);
	void dataTrans();	
	void print();
	void editCurves();

signals:
	void fileChanged();
	void popupQuit(int);
	void gfWidgetClicked( QMouseEvent *m );
	void pointClicked(int,int);
	
private:

	void paintEvent(QPaintEvent *);
	void resizeEvent(QResizeEvent *);
	void mousePressEvent ( QMouseEvent * );
	
	void draw(QPaintDevice *w);
	
	GfFile gffile;
	
	GfDraw gfdraw;
	
	GfScale gfscale;
	
	GfPlotDefs plotdefs;

	int popup_enabled;
	
	QPopupMenu *settingspopup;
	
	QPopupMenu *filepopup;
	
	void errorBox(const char *);
	
	void open_append(QString fileName, int append);
	
	int selection_curve,selection_start,selection_end;
	
	int use_pixmap_redraw;
	
	QPixmap *redraw_pixmap;
		
};
#endif // GfWidget_included
